"""
Python module generated from Java source file dev.magicmq.pyspigot.bukkit.manager.script.BukkitScriptManager

Java source file obtained from artifact pyspigot-bukkit version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import PyCore
from dev.magicmq.pyspigot.bukkit import PySpigot
from dev.magicmq.pyspigot.bukkit.event import ScriptExceptionEvent
from dev.magicmq.pyspigot.bukkit.event import ScriptLoadEvent
from dev.magicmq.pyspigot.bukkit.event import ScriptUnloadEvent
from dev.magicmq.pyspigot.bukkit.manager.placeholder import PlaceholderManager
from dev.magicmq.pyspigot.bukkit.manager.protocol import ProtocolManager
from dev.magicmq.pyspigot.bukkit.manager.script import *
from dev.magicmq.pyspigot.exception import InvalidConfigurationException
from dev.magicmq.pyspigot.manager.script import Script
from dev.magicmq.pyspigot.manager.script import ScriptManager
from dev.magicmq.pyspigot.manager.script import ScriptOptions
from java.nio.file import Path
from org.bukkit import Bukkit
from org.bukkit.scheduler import BukkitTask
from org.python.core import PyException
from typing import Any, Callable, Iterable, Tuple


class BukkitScriptManager(ScriptManager):
    """
    The Bukkit-specific implementation of the script manager.
    """

    def scheduleStartScriptTask(self) -> None:
        ...


    def cancelStartScriptTask(self) -> None:
        ...


    def isPluginDependencyMissing(self, dependency: str) -> bool:
        ...


    def callScriptExceptionEvent(self, script: "Script", exception: "PyException") -> bool:
        ...


    def callScriptLoadEvent(self, script: "Script") -> None:
        ...


    def callScriptUnloadEvent(self, script: "Script", error: bool) -> None:
        ...


    def newScriptOptions(self) -> "ScriptOptions":
        ...


    def newScriptOptions(self, scriptName: str) -> "ScriptOptions":
        ...


    def newScript(self, path: "Path", name: str, options: "ScriptOptions") -> "Script":
        ...


    def initScriptPermissions(self, script: "Script") -> None:
        ...


    def removeScriptPermissions(self, script: "Script") -> None:
        ...


    def unregisterFromPlatformManagers(self, script: "Script") -> None:
        ...


    @staticmethod
    def get() -> "BukkitScriptManager":
        """
        Get the singleton instance of this BukkitScriptManager.

        Returns
        - The instance
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.bukkit.event.custom.CustomEvent

Java source file obtained from artifact pyspigot-bukkit version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.bukkit.event import ScriptEvent
from dev.magicmq.pyspigot.bukkit.event.custom import *
from dev.magicmq.pyspigot.util import ScriptUtils
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.python.core import Py
from org.python.core import PyObject
from typing import Any, Callable, Iterable, Tuple


class CustomEvent(ScriptEvent, Cancellable):
    """
    A custom event that scripts may instantiate and call for other plugins/scripts to listen to.
    """

    def __init__(self, name: str, data: Any):
        """
        
        **Note:** This class should be instantiated from scripts only!

        Arguments
        - name: The name of the event being created. Can be used to create subtypes of the generic custom event
        - data: The data to attach to the event
        """
        ...


    def __init__(self, name: str, data: Any, async: bool):
        """
        
        **Note:** This class should be instantiated from scripts only!

        Arguments
        - name: The name of the event being created. Can be used to create subtypes of the generic custom event
        - data: The data to attach to the event
        - async: Whether the event is being called from an asynchronous context
        """
        ...


    def getName(self) -> str:
        """
        Get the name of this event.

        Returns
        - The name of this event
        """
        ...


    def getData(self) -> Any:
        """
        Get the data attached to this event.

        Returns
        - The data attached to this event
        """
        ...


    def getDataAsType(self, clazz: str) -> "Object":
        """
        Attempt to convert the data attached to this event to a provided type.

        Arguments
        - clazz: The type that the data should be converted to

        Returns
        - An object of the specified type representing the converted data

        Raises
        - org.python.core.PyException: If the data could not be converted to the provided type
        """
        ...


    def getDataAsType(self, clazz: type["T"]) -> "T":
        """
        Attempt to convert the data attached to this event to a provided type.
        
        Type `<T>`: The type to which the data should be converted

        Arguments
        - clazz: The type that the data should be converted to

        Returns
        - An object of the specified type representing the converted data

        Raises
        - org.python.core.PyException: If the data could not be converted to the provided type
        """
        ...


    def isCancelled(self) -> bool:
        """

        """
        ...


    def setCancelled(self, cancelled: bool) -> None:
        """

        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.bukkit.manager.protocol.ListenerType

Java source file obtained from artifact pyspigot-bukkit version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.bukkit.manager.protocol import *
from enum import Enum
from typing import Any, Callable, Iterable, Tuple


class ListenerType(Enum):
    """
    An enum representing the type of protocol listener that a script has registered.
    """

    NORMAL = 0
    """
    A normal listner.
    """
    ASYNCHRONOUS = 1
    """
    An asynchronous listener.
    """
    ASYNCHRONOUS_TIMEOUT = 2
    """
    An asynchronous timeout listener.
    """



"""
Python module generated from Java source file dev.magicmq.pyspigot.manager.config.ScriptConfig

Java source file obtained from artifact pyspigot-core version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.manager.config import *
from java.io import File
from java.io import IOException
from java.nio.file import Path
from typing import Any, Callable, Iterable, Tuple


class ScriptConfig:
    """
    Represents a config file belonging to a script. Meant to be implemented by a class that also implements/extends a platform-specific configuration API.
    """

    def getConfigFile(self) -> "File":
        """
        Get the file associated with this configuration.

        Returns
        - The file associated with this configuration
        """
        ...


    def getConfigPath(self) -> "Path":
        """
        Get the absolute path of the file associated with this configuration.

        Returns
        - The path of the file
        """
        ...


    def load(self) -> None:
        """
        Loads the config from the configuration file. Will also set defaults for the configuration, if they were specified.

        Raises
        - IOException: If there was an exception when loading the file
        """
        ...


    def reload(self) -> None:
        """
        Reload the configuration. Will read all changes made to the configuration file since the configuration was last loaded/reloaded.

        Raises
        - IOException: If there was an exception when loading the file
        """
        ...


    def save(self) -> None:
        """
        Save the configuration to its associated file. For continuity purposes, the configuration is also reloaded from the file after saving.

        Raises
        - IOException: If there is an IOException when saving the file
        """
        ...


    def setIfNotExists(self, path: str, value: "Object") -> bool:
        """
        Sets the specified path to the given value only if the path is not already set in the config file. Any specified default values are ignored when checking if the path is set.

        Arguments
        - path: Path of the object to set
        - value: Value to set the path to

        Returns
        - True if the path was set to the value (in other words the path was not previously set), False if the path was not set to the value (in other words the path was already previously set)
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.manager.libraries.LibraryManager

Java source file obtained from artifact pyspigot-core version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import PyCore
from dev.magicmq.pyspigot.manager.libraries import *
from enum import Enum
from java.io import File
from java.io import IOException
from java.util import Arrays
from java.util import SortedSet
from java.util.concurrent import Callable
from java.util.concurrent import ExecutorService
from java.util.concurrent import Executors
from me.lucko.jarrelocator import JarRelocator
from typing import Any, Callable, Iterable, Tuple


class LibraryManager:
    """
    A manager class to help with dynamically loading Jar files into the classpath at runtime. Most commonly, scripts will not use this directly and PySpigot will be the primary user of this manager.
    
    Internally, this utilizes the jar-relocator library from lucko to dynamically load Jar files at runtime.

    See
    - me.lucko.jarrelocator.JarRelocator
    """

    def shutdown(self) -> None:
        """
        Closes the class loader for scripts.
        """
        ...


    def reload(self) -> None:
        """
        Attempts to load all libraries that are not currently loaded. Libraries that are already loaded will be unaffected.
        """
        ...


    def loadLibrary(self, libName: str) -> "LoadResult":
        """
        Load a library into the classpath.

        Arguments
        - libName: The name of the Jar file to load into the classpath, including the extension (.jar)

        Returns
        - A LoadResult describing the outcome of the load attempt
        """
        ...


    def getClassLoader(self) -> "JarClassLoader":
        """
        Get the JarClassLoader for loading Jar files into the classpath.

        Returns
        - The JarClassLoader
        """
        ...


    @staticmethod
    def get() -> "LibraryManager":
        """
        Get the singleton instance of this LibraryManager.

        Returns
        - The instance
        """
        ...


    class LoadResult(Enum):
        """
        An enum representing the outcome of an attempt to load a library.
        """

        FAILED_FILE = 0
        """
        The library failed to load because the libs folder does not exist.
        """
        FAILED_LOADED = 1
        """
        The library failed to load because it is already loaded.
        """
        FAILED_ERROR = 2
        """
        The library failed to load because of some unrecoverable error.
        """
        SUCCESS = 3
        """
        The library loaded successfully.
        """



"""
Python module generated from Java source file dev.magicmq.pyspigot.bukkit.manager.listener.BukkitScriptEventListener

Java source file obtained from artifact pyspigot-bukkit version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.bukkit.manager.listener import *
from dev.magicmq.pyspigot.manager.script import Script
from org.bukkit.event import Event
from org.bukkit.event import Listener
from org.python.core import PyFunction
from typing import Any, Callable, Iterable, Tuple


class BukkitScriptEventListener(Listener):
    """
    A dummy Bukkit Listener that holds an event a script is currently listening to.

    See
    - org.bukkit.event.Listener
    """

    def __init__(self, script: "Script", listenerFunction: Callable, event: type["Event"]):
        """
        Arguments
        - script: The script listening to events within this listener
        - listenerFunction: The script function that should be called when the event occurs
        - event: The Bukkit event associated with this listener. Should be a Class of the Bukkit event
        """
        ...


    def getScript(self) -> "Script":
        """
        Get the script associated with this listener.

        Returns
        - The script associated with this listener.
        """
        ...


    def getListenerFunction(self) -> Callable:
        """
        Get the script function that should be called when the event occurs.

        Returns
        - The script function that should be called when the event occurs
        """
        ...


    def getEvent(self) -> type["Event"]:
        """
        Get the Bukkit event associated with this listener.
        
        Note: Because of the way scripts register events, this will be a Class of the Bukkit event, which essentially represents its type.

        Returns
        - The Bukkit event associated with this listener.
        """
        ...


    def getEventExecutor(self) -> "BukkitScriptEventExecutor":
        """
        Get the BukkitScriptEventExecutor associated with this script event listener.

        Returns
        - The BukkitScriptEventExecutor associated with this script event listener
        """
        ...


    def toString(self) -> str:
        """
        Prints a representation of this BukkitScriptEventListener in string format, including the event being listened to by the listener

        Returns
        - A string representation of the ScriptEventListener
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.manager.redis.client.RedisCommandClient

Java source file obtained from artifact pyspigot-core version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.manager.redis.client import *
from dev.magicmq.pyspigot.manager.script import Script
from io.lettuce.core import ClientOptions
from io.lettuce.core import RedisURI
from io.lettuce.core.api import StatefulRedisConnection
from io.lettuce.core.api.async import RedisAsyncCommands
from io.lettuce.core.api.sync import RedisCommands
from typing import Any, Callable, Iterable, Tuple


class RedisCommandClient(ScriptRedisClient):
    """
    Extension of the ScriptRedisClient that provides ability to issue commands.

    See
    - io.lettuce.core.api.StatefulRedisConnection
    """

    def __init__(self, script: "Script", redisURI: "RedisURI", clientOptions: "ClientOptions"):
        """
        Arguments
        - script: The script to which this ScriptRedisCommandClient belongs
        - redisURI: The URI that specifies the connection details to the server
        - clientOptions: The io.lettuce.core.ClientOptions that should be used for the RedisClient
        """
        ...


    def open(self) -> None:
        """

        """
        ...


    def getConnection(self) -> "StatefulRedisConnection"[str, str]:
        """
        Get the underlying connection for this RedisCommandClient.

        Returns
        - The connection associated with this RedisCommandClient
        """
        ...


    def getCommands(self) -> "RedisCommands"[str, str]:
        """
        Get the io.lettuce.core.api.sync.RedisCommands object for executing commands **synchronously**.

        Returns
        - A RedisCommands object for executing commands

        See
        - io.lettuce.core.api.StatefulRedisConnection.sync()
        """
        ...


    def getAsyncCommands(self) -> "RedisAsyncCommands"[str, str]:
        """
        Get the io.lettuce.core.api.async.RedisAsyncCommands object for executing commands **asynchronously**.

        Returns
        - A RedisAsyncCommands object for executing commands

        See
        - io.lettuce.core.api.StatefulRedisConnection.async()
        """
        ...


    def toString(self) -> str:
        """
        Prints a representation of this RedisCommandClient in string format, including listeners

        Returns
        - A string representation of the RedisCommandClient
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.command.subcommands.LoadCommand

Java source file obtained from artifact pyspigot-core version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.command import SubCommand
from dev.magicmq.pyspigot.command import SubCommandMeta
from dev.magicmq.pyspigot.command.subcommands import *
from dev.magicmq.pyspigot.manager.script import RunResult
from dev.magicmq.pyspigot.manager.script import ScriptManager
from dev.magicmq.pyspigot.util.player import CommandSenderAdapter
from java.io import IOException
from net.md_5.bungee.api import ChatColor
from typing import Any, Callable, Iterable, Tuple


class LoadCommand(SubCommand):

    def onCommand(self, sender: "CommandSenderAdapter", args: list[str]) -> bool:
        ...


    def onTabComplete(self, sender: "CommandSenderAdapter", args: list[str]) -> list[str]:
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.PlatformAdapter

Java source file obtained from artifact pyspigot-core version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import *
from dev.magicmq.pyspigot.config import PluginConfig
from java.io import File
from java.nio.file import Path
from typing import Any, Callable, Iterable, Tuple


class PlatformAdapter:
    """
    An adapter class that wraps platform-specific code for plugin initialization, shutdown, and other plugin-related activities.
    """

    def initConfig(self) -> "PluginConfig":
        """
        Initialize the config file via a platform-specific implementation, saving the default config file in the process if it does not already exist.
        """
        ...


    def initCommands(self) -> None:
        """
        Initialize plugin commands via a platform-specific implementation.
        """
        ...


    def initListeners(self) -> None:
        """
        Initialize plugin listeners via a platform-specific implementation.
        """
        ...


    def initPlatformManagers(self) -> None:
        """
        Initialize managers that require a platform-specific implementation.
        
        Also initializes managers that are entirely specific to one platform (no core abstraction).
        """
        ...


    def initVersionChecking(self) -> None:
        """
        Initialize the version-checking task via a platform-specific implementation.
        """
        ...


    def setupMetrics(self) -> None:
        """
        Setup bStats metrics via a platform-specific implementation.
        """
        ...


    def shutdownMetrics(self) -> None:
        """
        Shutdown bStats metrics via a platform-specific implementation.
        """
        ...


    def shutdownVersionChecking(self) -> None:
        """
        Stop the version-checking task via a platform-specific implementation.
        """
        ...


    def getLogger(self) -> "Logger":
        """
        Get the logger for the plugin via a platform-specific implementation.

        Returns
        - The logger
        """
        ...


    def getDataFolder(self) -> "File":
        """
        Get the data folder for the plugin via a platform-specific implementation.

        Returns
        - The data folder
        """
        ...


    def getDataFolderPath(self) -> "Path":
        """
        Get the data folder path for the plugin via a platform-specific implementation.

        Returns
        - The data folder path
        """
        ...


    def getPluginClassLoader(self) -> "ClassLoader":
        """
        Get the class loader for the plugin via a platform-specific implementation.

        Returns
        - The class loader
        """
        ...


    def getVersion(self) -> str:
        """
        Get the plugin version via a platform-specific implementation.

        Returns
        - The plugin version
        """
        ...


    def getPluginIdentifier(self) -> str:
        """
        Get the appropriate plugin identifier, depending on the platform.

        Returns
        - The plugin identifier
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.util.player.PlayerAdapter

Java source file obtained from artifact pyspigot-core version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.util.player import *
from net.md_5.bungee.api.chat import BaseComponent
from typing import Any, Callable, Iterable, Tuple


class PlayerAdapter:
    """
    A utility class that wraps a platform-specific player object.
    """

    def hasPermission(self, permission: str) -> bool:
        """
        Check if the player has a permission via a platform-specific implementation.

        Arguments
        - permission: The permission to check

        Returns
        - True if the player has the permission, False if they do not
        """
        ...


    def sendMessage(self, message: list["BaseComponent"]) -> None:
        """
        Send a message to the player via a platform-specific implementation.

        Arguments
        - message: The message to send
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.command.SubCommandMeta

Java source file obtained from artifact pyspigot-core version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.command import *
from typing import Any, Callable, Iterable, Tuple


class SubCommandMeta:

    def command(self) -> str:
        ...


    def aliases(self) -> list[str]:
        return {}


    def permission(self) -> str:
        return ""


    def playerOnly(self) -> bool:
        return False


    def usage(self) -> str:
        return ""


    def description(self) -> str:
        return "No description provided."



"""
Python module generated from Java source file dev.magicmq.pyspigot.manager.script.ScriptInfo

Java source file obtained from artifact pyspigot-core version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import PyCore
from dev.magicmq.pyspigot.manager.command import CommandManager
from dev.magicmq.pyspigot.manager.database import Database
from dev.magicmq.pyspigot.manager.database import DatabaseManager
from dev.magicmq.pyspigot.manager.listener import ListenerManager
from dev.magicmq.pyspigot.manager.redis import RedisManager
from dev.magicmq.pyspigot.manager.redis.client import ScriptRedisClient
from dev.magicmq.pyspigot.manager.script import *
from dev.magicmq.pyspigot.manager.task import Task
from dev.magicmq.pyspigot.manager.task import TaskManager
from dev.magicmq.pyspigot.util import StringUtils
from java.nio.file import Path
from java.time import Duration
from net.md_5.bungee.api import ChatColor
from typing import Any, Callable, Iterable, Tuple


class ScriptInfo:
    """
    A utility class that fetches and returns a script's info.
    """

    def printPlatformManagerInfo(self, script: "Script", appendTo: "StringBuilder") -> None:
        """
        Print platform-specific manager information for a script.

        Arguments
        - script: The script whose information should be printed
        - appendTo: The info StringBuilder that platform-specific manager info should be appended to
        """
        ...


    def printScriptInfo(self, script: "Script") -> str:
        """
        Print a script's info (for the /pyspigot info command).

        Arguments
        - script: The script whose information should be printed

        Returns
        - The info for the script
        """
        ...


    def printOfflineScriptInfo(self, scriptName: str, scriptPath: "Path", options: "ScriptOptions") -> str:
        """
        Print a script's info (for the /pyspigot info command), if the script is not loaded.

        Arguments
        - scriptName: The name of the script whose information should be printed
        - scriptPath: The path of the script
        - options: The options of the script

        Returns
        - The info for the script
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.bukkit.event.ScriptLoadEvent

Java source file obtained from artifact pyspigot-bukkit version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.bukkit.event import *
from dev.magicmq.pyspigot.manager.script import Script
from org.bukkit.event import HandlerList
from typing import Any, Callable, Iterable, Tuple


class ScriptLoadEvent(ScriptEvent):
    """
    Called when a script is loaded. This event fires at the end of a load operation on a script. The event will not fire for scripts that fail to load. Therefore, it is safe to assume the script within this event is currently running.
    """

    def __init__(self, script: "Script"):
        """
        Arguments
        - script: The script that was loaded
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.manager.task.RepeatingTask

Java source file obtained from artifact pyspigot-core version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.manager.script import Script
from dev.magicmq.pyspigot.manager.script import ScriptManager
from dev.magicmq.pyspigot.manager.task import *
from org.python.core import Py
from org.python.core import PyException
from org.python.core import PyFunction
from org.python.core import PyObject
from typing import Any, Callable, Iterable, Tuple


class RepeatingTask(Task):
    """
    Represents a repeating task defined by a script.
    """

    def __init__(self, script: "Script", function: Callable, functionArgs: list["Object"], async: bool, delay: int, interval: int):
        """
        Arguments
        - script: The script associated with this repeating task
        - function: The script function that should be called every time the repeating task executes
        - functionArgs: Any arguments that should be passed to the function
        - async: True if the task is asynchronous, False if otherwise
        - delay: The delay, in ticks, to wait until running the task
        - interval: The interval, in ticks, between each repeat of the task
        """
        ...


    def run(self) -> None:
        """

        """
        ...


    def toString(self) -> str:
        """
        Prints a representation of this RepeatingTask in string format, including the task ID, if it is async, delay (if applicable), and interval (if applicable)

        Returns
        - A string representation of the RepeatingTask
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.bukkit.command.BukkitPluginCommand

Java source file obtained from artifact pyspigot-bukkit version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.bukkit.command import *
from dev.magicmq.pyspigot.bukkit.util.player import BukkitCommandSender
from dev.magicmq.pyspigot.command import PySpigotCommand
from dev.magicmq.pyspigot.util.player import CommandSenderAdapter
from org.bukkit.command import Command
from org.bukkit.command import CommandSender
from org.bukkit.command import TabExecutor
from typing import Any, Callable, Iterable, Tuple


class BukkitPluginCommand(TabExecutor):
    """
    The executor for the /pyspigot command.
    """

    def __init__(self):
        ...


    def onCommand(self, sender: "CommandSender", command: "Command", label: str, args: list[str]) -> bool:
        ...


    def onTabComplete(self, sender: "CommandSender", command: "Command", alias: str, args: list[str]) -> list[str]:
        ...



"""
A helper module for more easy access to PySpigot's managers.
"""
from dev.magicmq.pyspigot.bukkit import PySpigot
from dev.magicmq.pyspigot.manager.script import ScriptManager
from dev.magicmq.pyspigot.manager.script import GlobalVariables
from dev.magicmq.pyspigot.manager.listener import ListenerManager
from dev.magicmq.pyspigot.manager.command import CommandManager
from dev.magicmq.pyspigot.manager.task import TaskManager
from dev.magicmq.pyspigot.manager.config import ConfigManager
from dev.magicmq.pyspigot.manager.database import DatabaseManager
from dev.magicmq.pyspigot.manager.redis import RedisManager

def script_manager():
    """Get the script manager for loading, unloading, and reloading scripts."""
    return ScriptManager.get()

def global_variables():
    """Get the global variables manager for setting and getting global variables."""
    return GlobalVariables.get()

def listener_manager():
    """Get the listener manager for registering and unregistering event listeners."""
    return ListenerManager.get()

def command_manager():
    """Get the command manager for registering and unregistering commands."""
    return CommandManager.get()

def task_manager():
    """Get the task manager for scheduling and unscheduling tasks (synchronous and asynchronous)."""
    return TaskManager.get()

def config_manager():
    """Get the config manager for writing to and reading from config files."""
    return ConfigManager.get()

def database_manager():
    """Get the database manager for connecting to and interacting with databases."""
    return DatabaseManager.get()

def redis_manager():
    """Get the redis manager for connecting to and interacting with redis servers."""
    return RedisManager.get()

def protocol_manager():
    """Get the protocol manager for working with ProtocolLib (registering/unregistering packet listeners, sending packets, etc.). Note: this function will return None if ProtocolLib is not available on the server."""
    if PySpigot.get().isProtocolLibAvailable():
        from dev.magicmq.pyspigot.bukkit.manager.protocol import ProtocolManager
        return ProtocolManager.get()
    else: return None

def placeholder_manager():
    """Get the placeholder manager for registering/unregistering PlaceholderAPI placeholders. Note: this function will return None if PlaceholderAPI is not available on the server."""
    if PySpigot.get().isPlaceholderApiAvailable():
        from dev.magicmq.pyspigot.bukkit.manager.placeholder import PlaceholderManager
        return PlaceholderManager.get()
    else: return None

# Convenience variables for ease of access

script = script_manager()
scripts = script_manager()
sm = script_manager()

global_vars = global_variables()
gv = global_variables()

listener = listener_manager()
listeners = listener_manager()
lm = listener_manager()
event = listener_manager()
events = listener_manager()
em = listener_manager()

command = command_manager()
commands = command_manager()
cm = command_manager()

scheduler = task_manager()
scm = task_manager()
tasks = task_manager()
tm = task_manager()

config = config_manager()
configs = config_manager()
com = config_manager()

database = database_manager()

redis = redis_manager()

protocol = protocol_manager()
protocol_lib = protocol_manager()
protocols = protocol_manager()
pm = protocol_manager()

placeholder = placeholder_manager()
placeholder_api = placeholder_manager()
placeholders = placeholder_manager()
plm = placeholder_manager()


"""
Python module generated from Java source file dev.magicmq.pyspigot.util.logging.ScriptLogger

Java source file obtained from artifact pyspigot-core version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import PyCore
from dev.magicmq.pyspigot.manager.script import Script
from dev.magicmq.pyspigot.util.logging import *
from java.io import IOException
from java.io import PrintWriter
from java.io import StringWriter
from java.nio.file import Path
from java.time import ZoneId
from java.time import ZonedDateTime
from typing import Any, Callable, Iterable, Tuple


class ScriptLogger(Logger):
    """
    A subclass of Logger that represents a script's logger.

    See
    - Logger
    """

    def __init__(self, script: "Script"):
        """
        Arguments
        - script: The script associated with this logger
        """
        ...


    def initFileHandler(self) -> None:
        """
        Initializes the FileHandler to log script log messages to its respective log file.

        Raises
        - IOException: If there was an IOException when initializing the FileHandler for this logger
        """
        ...


    def closeFileHandler(self) -> None:
        """
        Closes the FileHandler for this logger. Should only be called if script file logging is enabled.
        """
        ...


    def print(self, logText: str) -> None:
        """
        A convenience method added for a script to print debug information to console and its log file.

        Arguments
        - logText: The message to print
        """
        ...


    def debug(self, logText: str) -> None:
        """
        A convenience method added for a script to print debug information to console and its log file.

        Arguments
        - logText: The message to print
        """
        ...


    def log(self, logRecord: "LogRecord") -> None:
        """

        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.manager.database.mongo.MongoDatabase

Java source file obtained from artifact pyspigot-core version 0.8.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.mongodb import BasicDBObject
from com.mongodb import MongoClientSettings
from com.mongodb.client import FindIterable
from com.mongodb.client import ListCollectionNamesIterable
from com.mongodb.client import ListCollectionsIterable
from com.mongodb.client import MongoClient
from com.mongodb.client import MongoClients
from com.mongodb.client import MongoCollection
from com.mongodb.client import MongoIterable
from com.mongodb.client.model import FindOneAndUpdateOptions
from com.mongodb.client.model import ReturnDocument
from com.mongodb.client.model import UpdateOptions
from com.mongodb.client.result import DeleteResult
from com.mongodb.client.result import InsertManyResult
from com.mongodb.client.result import InsertOneResult
from com.mongodb.client.result import UpdateResult
from dev.magicmq.pyspigot.manager.database import Database
from dev.magicmq.pyspigot.manager.database.mongo import *
from dev.magicmq.pyspigot.manager.script import Script
from java.util import Collections
from org.bson import Document
from org.bson.conversions import Bson
from typing import Any, Callable, Iterable, Tuple


class MongoDatabase(Database):
    """
    Represents an open connection to a Mongo Database.
    
    **Note:** Most methods in this class should be called from scripts only!
    """

    def __init__(self, script: "Script", clientSettings: "MongoClientSettings"):
        """
        Arguments
        - script: The script associated with this MongoDatabase
        - clientSettings: The client settings for the MongoDatabase connection
        """
        ...


    def open(self) -> bool:
        """

        """
        ...


    def close(self) -> bool:
        """

        """
        ...


    def getMongoClient(self) -> "MongoClient":
        """
        Get the com.mongodb.client.MongoClient associated with this Mongo Database connection.

        Returns
        - The MongoClient
        """
        ...


    def fetchNewUpdateOptions(self) -> "UpdateOptions":
        """
        Fetch a new com.mongodb.client.model.UpdateOptions object for updates
        """
        ...


    def fetchNewFindOneAndUpdateOptions(self) -> "FindOneAndUpdateOptions":
        """
        Fetch a new com.mongodb.client.model.FindOneAndUpdateOptions object for updates
        """
        ...


    def createObject(self) -> "BasicDBObject":
        """
        Create a new empty com.mongodb.BasicDBObject.

        Returns
        - The BasicDBObject
        """
        ...


    def createObject(self, json: str) -> "BasicDBObject":
        """
        Create a new com.mongodb.BasicDBObject out of the provided json.

        Returns
        - The BasicDBObject
        """
        ...


    def createObject(self, key: str, value: "Object") -> "BasicDBObject":
        """
        Create a new com.mongodb.BasicDBObject with the provided key and value.

        Returns
        - The BasicDBObject
        """
        ...


    def createDocument(self) -> "Document":
        """
        Create an empty org.bson.Document.

        Returns
        - The document
        """
        ...


    def createDocument(self, json: str) -> "Document":
        """
        Create a org.bson.Document out of the provided json.

        Arguments
        - json: A JSON representation of the document

        Returns
        - The document
        """
        ...


    def createDocument(self, key: str, value: "Object") -> "Document":
        """
        Create a org.bson.Document with the provided key and value.

        Arguments
        - key: The key
        - value: The value

        Returns
        - The document
        """
        ...


    def getDatabase(self, database: str) -> "com.mongodb.client.MongoDatabase":
        """
        Get a com.mongodb.client.MongoDatabase with the given name.

        Arguments
        - database: The name of the database

        Returns
        - The database
        """
        ...


    def getDatabaseNames(self) -> "MongoIterable"[str]:
        """
        Get all database names.

        Returns
        - An iterable list of type com.mongodb.client.MongoIterable<String> containing all database names
        """
        ...


    def getDatabases(self) -> "MongoIterable"["Document"]:
        """
        Get all databases.

        Returns
        - An iterable list of type com.mongodb.client.MongoIterable<Document> containing all databases
        """
        ...


    def doesDatabaseExist(self, database: str) -> bool:
        """
        Check if a database exists with the given name.

        Arguments
        - database: The name of the database to check

        Returns
        - True if the database exists, False if otherwise
        """
        ...


    def createCollection(self, database: str, collection: str) -> bool:
        """
        Create a collection in the given database

        Arguments
        - database: The name of the database where the collection should be created
        - collection: The name for the collection

        Returns
        - True if the collection was created, False if it already exists in the database
        """
        ...


    def deleteCollection(self, database: str, collection: str) -> bool:
        """
        Delete a collection in the given database

        Arguments
        - database: The name of the database where the collection should be deleted
        - collection: The name of the collection

        Returns
        - True if the collection was deleted, False if it did not exist in the database
        """
        ...


    def getCollection(self, database: str, collection: str) -> "MongoCollection"["Document"]:
        """
        Get a collection from a database.

        Arguments
        - database: The name of the database to fetch from
        - collection: The name of the collection to get

        Returns
        - A com.mongodb.client.MongoCollection<Document> containing org.bson.Document representing the collection
        """
        ...


    def getCollectionNames(self, database: str) -> "ListCollectionNamesIterable":
        """
        Get all collection names within a database.

        Arguments
        - database: The database to get collections names from

        Returns
        - An iterable list of type com.mongodb.client.ListCollectionNamesIterable containing all collection names
        """
        ...


    def getCollections(self, database: str) -> "ListCollectionsIterable"["Document"]:
        """
        Get all collections within a database.

        Arguments
        - database: The database to get collections from

        Returns
        - An iterable list of type com.mongodb.client.ListCollectionsIterable<Document> containing all collections
        """
        ...


    def doesCollectionExist(self, database: str, collection: str) -> bool:
        """
        Check if a collection exists within a database.

        Arguments
        - database: The name of the database to check
        - collection: The name of the collection to check

        Returns
        - True if the collection exists, False if otherwise
        """
        ...


    def createCollectionIndex(self, database: str, collection: str, keys: "Bson") -> str:
        """
        Create a collection with an index of the given keys.

        Arguments
        - database: The name of the database where the collection should be created
        - collection: The name for the collection
        - keys: A org.bson.conversions.Bson object representing the index keys

        Returns
        - 
        """
        ...


    def getDocument(self, database: str, collection: str, filter: "Bson") -> "Document":
        """
        Get a document within a collection that match the given filter.

        Arguments
        - database: The name of the database to fetch from
        - collection: The name of the collection to fetch from
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection

        Returns
        - The first document within the collection that matched the provided filter
        """
        ...


    def getDocument(self, database: str, collection: str, filter: "Bson", projections: "Bson", sorts: "Bson") -> "Document":
        """
        Get a document within a collection that match the given filter, projections, and sort criteria.

        Arguments
        - database: The name of the database to fetch from
        - collection: The name of the collection to fetch from
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - projections: The project document
        - sorts: Sort criteria

        Returns
        - The first document within the collection that matched the provided filter, projections, and sort criteria
        """
        ...


    def getDocuments(self, database: str, collection: str) -> "FindIterable"["Document"]:
        """
        Get all documents within a collection.

        Arguments
        - database: The name of the database to fetch from
        - collection: The name of the collection to fetch from

        Returns
        - An iterable list of type com.mongodb.client.FindIterable<Document> containing all documents within the collection
        """
        ...


    def getDocuments(self, database: str, collection: str, filter: "Bson") -> "FindIterable"["Document"]:
        """
        Get all documents within a collection that match the given filter.

        Arguments
        - database: The name of the database to fetch from
        - collection: The name of the collection to fetch from
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection

        Returns
        - An iterable list of type com.mongodb.client.FindIterable<Document> containing all documents within the collection that matched the provided filter
        """
        ...


    def insertDocument(self, database: str, collection: str, document: "Document") -> "InsertOneResult":
        """
        Insert a document into a collection.

        Arguments
        - database: The database that contains the collection
        - collection: The collection to insert into
        - document: The document to insert

        Returns
        - An com.mongodb.client.result.InsertOneResult representing the outcome of the operation
        """
        ...


    def insertDocuments(self, database: str, collection: str, documents: list["Document"]) -> "InsertManyResult":
        """
        Insert multiple documents into a collection.

        Arguments
        - database: The database that contains the collection
        - collection: The collection to insert into
        - documents: The documents to insert

        Returns
        - An com.mongodb.client.result.InsertManyResult representing the outcome of the operation
        """
        ...


    def updateDocument(self, database: str, collection: str, filter: "Bson", update: "Bson") -> "UpdateResult":
        """
        Update one or more documents within a collection that match the given filter, with the default update options

        Arguments
        - database: The database that contains the collection
        - collection: The collection containing the document
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - update: The update that should be applied to the first matching document

        Returns
        - An com.mongodb.client.result.UpdateResult representing the outcome of the operation
        """
        ...


    def updateDocument(self, database: str, collection: str, filter: "Bson", update: "Bson", updateOptions: "UpdateOptions") -> "UpdateResult":
        """
        Update one or more documents within a collection that match the given filter, with the provided update options

        Arguments
        - database: The database that contains the collection
        - collection: The collection containing the document
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - update: The update that that should be applied to the first matching document
        - updateOptions: A com.mongodb.client.model.UpdateOptions object representing the options to apply to the update operation

        Returns
        - An com.mongodb.client.result.UpdateResult representing the outcome of the operation
        """
        ...


    def updateDocument(self, database: str, collection: str, filter: "Bson", updates: list["Bson"]) -> "UpdateResult":
        """
        Update one or more documents within a collection that match the given filter, with the default update options

        Arguments
        - database: The database that contains the collection
        - collection: The collection containing the document
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - updates: The updates that should be applied to the first matching document

        Returns
        - An com.mongodb.client.result.UpdateResult representing the outcome of the operation
        """
        ...


    def updateDocument(self, database: str, collection: str, filter: "Bson", updates: list["Bson"], updateOptions: "UpdateOptions") -> "UpdateResult":
        """
        Update one or more documents within a collection that match the given filter, with the provided update options

        Arguments
        - database: The database that contains the collection
        - collection: The collection containing the document
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - updates: The updates that should be applied to the first matching document
        - updateOptions: A com.mongodb.client.model.UpdateOptions object representing the options to apply to the update operation

        Returns
        - An com.mongodb.client.result.UpdateResult representing the outcome of the operation
        """
        ...


    def findAndUpdateDocument(self, database: str, collection: str, filter: "Bson", update: "Bson") -> "Document":
        """
        Update and return a document within a collection that match the given filter, with the default update options

        Arguments
        - database: The database that contains the collection
        - collection: The collection containing the document
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - update: The update that should be applied to the first matching document

        Returns
        - An com.mongodb.client.result.UpdateResult representing the outcome of the operation
        """
        ...


    def findAndUpdateDocument(self, database: str, collection: str, filter: "Bson", update: "Bson", updateOptions: "FindOneAndUpdateOptions") -> "Document":
        """
        Update and return a document within a collection that match the given filter, with the default update options

        Arguments
        - database: The database that contains the collection
        - collection: The collection containing the document
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - update: The update that should be applied to the first matching document
        - updateOptions: A com.mongodb.client.model.FindOneAndUpdateOptions object representing the options to apply to the update operation

        Returns
        - The document that was updated
        """
        ...


    def findAndUpdateDocument(self, database: str, collection: str, filter: "Bson", update: list["Bson"]) -> "Document":
        """
        Update and return a document within a collection that match the given filter, with the default update options

        Arguments
        - database: The database that contains the collection
        - collection: The collection containing the document
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - update: The updates that should be applied to the first matching document

        Returns
        - The document that was updated
        """
        ...


    def findAndUpdateDocument(self, database: str, collection: str, filter: "Bson", update: list["Bson"], updateOptions: "FindOneAndUpdateOptions") -> "Document":
        """
        Update and return a document within a collection that match the given filter, with the default update options

        Arguments
        - database: The database that contains the collection
        - collection: The collection containing the document
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - update: The updates that should be applied to the first matching document
        - updateOptions: A com.mongodb.client.model.FindOneAndUpdateOptions object representing the options to apply to the update operation

        Returns
        - The document that was updated
        """
        ...


    def updateDocuments(self, database: str, collection: str, filter: "Bson", update: "Bson") -> "UpdateResult":
        """
        Update multiple documents within a collection.

        Arguments
        - database: The database that contains the collection
        - collection: The collection whose documents should be updated
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - update: The update that should be applied to all matching documents

        Returns
        - An com.mongodb.client.result.UpdateResult representing the outcome of the operation
        """
        ...


    def updateDocuments(self, database: str, collection: str, filter: "Bson", update: "Bson", updateOptions: "UpdateOptions") -> "UpdateResult":
        """
        Update multiple documents within a collection.

        Arguments
        - database: The database that contains the collection
        - collection: The collection whose documents should be updated
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - update: The update that should be applied to all matching documents
        - updateOptions: A com.mongodb.client.model.UpdateOptions object representing the options to apply to the update operation

        Returns
        - An com.mongodb.client.result.UpdateResult representing the outcome of the operation
        """
        ...


    def updateDocuments(self, database: str, collection: str, filter: "Bson", update: list["Bson"]) -> "UpdateResult":
        """
        Update multiple documents within a collection.

        Arguments
        - database: The database that contains the collection
        - collection: The collection whose documents should be updated
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - update: The updates that should be applied to all matching documents

        Returns
        - An com.mongodb.client.result.UpdateResult representing the outcome of the operation
        """
        ...


    def updateDocuments(self, database: str, collection: str, filter: "Bson", update: list["Bson"], updateOptions: "UpdateOptions") -> "UpdateResult":
        """
        Update multiple documents within a collection.

        Arguments
        - database: The database that contains the collection
        - collection: The collection whose documents should be updated
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection
        - update: The updates that should be applied to all matching documents
        - updateOptions: A com.mongodb.client.model.UpdateOptions object representing the options to apply to the update operation

        Returns
        - An com.mongodb.client.result.UpdateResult representing the outcome of the operation
        """
        ...


    def deleteDocument(self, database: str, collection: str, filter: "Bson") -> "DeleteResult":
        """
        Delete a document from a collection matching the provided filter.

        Arguments
        - database: The database that contains the collection
        - collection: The collection that contains the document
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection

        Returns
        - An com.mongodb.client.result.DeleteResult representing the outcome of the operation
        """
        ...


    def deleteDocuments(self, database: str, collection: str, filter: "Bson") -> "DeleteResult":
        """
        Delete multiple documents from a collection matching the provided filter.

        Arguments
        - database: The database that contains the collection
        - collection: The collection that contains the documents
        - filter: A org.bson.conversions.Bson object representing a filter to filter documents within the collection

        Returns
        - An com.mongodb.client.result.DeleteResult representing the outcome of the operation
        """
        ...


    def toString(self) -> str:
        """
        Prints a representation of this MongoDatabase in string format, including the URI and com.mongodb.client.MongoClient

        Returns
        - A string representation of the MongoDatabase
        """
        ...
